import hypermedia.video.*;
import java.awt.*;

OpenCV opencv;
int vw = 320, vh = 240;

void setup() {

    size( 960, 240 );

    opencv = new OpenCV( this );
    opencv.capture(vw, vh);
}

void draw() {
    // grab frame from camera --------------------------------
    opencv.read();
    
    // draw camera image on the left -------------------------
    image(opencv.image(), 0, 0);
    
    // make a duotone image -> several threshold calcualtions available
    // move mouse on x axis to adjust threshold
    float thresh = map(mouseX, 0, 255, 0, width);
    opencv.threshold(thresh); 
    
    // draw duotone image in the middle ----------------------
    image(opencv.image(), 320, 0);

   
    // draw blobs on the right -------------------------------   
    pushMatrix();
    translate(2 * vw, 0);
    
    // draw background
    noStroke();
    fill(200);
    rect(0,0, vw, vh);


    // find contours/ blobs in image -----------
    // adjust minArea, maxArea, maxBlobs, findHoles, maxVertices
    Blob[] blobs = opencv.blobs( 100, width*height/2, 100, true, OpenCV.MAX_VERTICES*4 );

    // draw blob results -------------------------------------
    
    for( int i=0; i<blobs.length; i++ ) {
        
        // contours of the blob ------------------   
        stroke(255,0,0);
        fill(255);    
        beginShape();
        for( int j=0; j<blobs[i].points.length; j++ ) {
            vertex( blobs[i].points[j].x, blobs[i].points[j].y );
        }
        endShape(CLOSE);
        
        // rectangle around blob -----------------
        Rectangle bounding_rect	= blobs[i].rectangle;
        float area = blobs[i].area;
        float circumference = blobs[i].length;

        Point centroid = blobs[i].centroid;
        Point[] points = blobs[i].points;

        // rectangle
        noFill();
        stroke( blobs[i].isHole ? 128 : 64 );
        rect( bounding_rect.x, bounding_rect.y, bounding_rect.width, bounding_rect.height );

        text( "# " + i, centroid.x+5, centroid.y-15 );
        
        // centroid
        stroke(0,0,255);
        line( centroid.x-5, centroid.y, centroid.x+5, centroid.y );
        line( centroid.x, centroid.y-5, centroid.x, centroid.y+5 );
        noStroke();
        fill(0,0,255);
        text( "fläche " + area,centroid.x+5, centroid.y+5 );
        
        noStroke();
        //fill(0,0,255);
        text( "umfang " + circumference, centroid.x+5, centroid.y+15 );
        //noFill();
    }
  
    popMatrix();

}



public void stop() {
    opencv.stop();
    super.stop();
}
